Description Usage Arguments Value Examples
View source: R/base_functions.R
Compute conformal prediction bands based on density estimation on new samples
1 2 |
cd_split_fit |
# Object of the class predictionBands, fitted using function |
xnew |
# new covariates (one per row) where prediction bands are to be computed |
type |
# type of prediction bands. dist for 'dist-split' and cd for 'cd-split'. |
alpha |
# Miscoverage level (defaults to 10%) |
Object of the class 'bands' with the following components:
y_grid |
Grid of values for y |
densities |
Matrix where each row contains the estimated density of the corresponding row of xnew on each value of y_grid |
ths |
thresholds agains which to compare conformal scores. |
prediction_bands_which_belong |
List with logical values with the same size as nrow(xnew); each element contains shows which elements of y_grid are contained on the prediction bands of the corresponding row of xnew |
intervals |
List with the same size as nrow(xnew) that contains the prediction bands for each element of xnew. For cd-split, results are shown as a union of disjoint intervals. |
type |
Type of prediction band |
alpha |
Miscoverage level |
1 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.